@@ -1,11 +1,27 @@
 from gears.asset_attributes import AssetAttributes
-from gears.compilers import BaseCompiler, CoffeeScriptCompiler, StylusCompiler
+from gears.compilers import BaseCompiler
 from gears.environment import Environment
 
 from mock import Mock
 from unittest2 import TestCase
 
 
+class StylusCompiler(BaseCompiler):
+
+    result_mimetype = 'text/css'
+
+    def __call__(self, asset):
+        pass
+
+
+class CoffeeScriptCompiler(BaseCompiler):
+
+    result_mimetype = 'application/javascript'
+
+    def __call__(self, asset):
+        pass
+
+
 class TemplateCompiler(BaseCompiler):
 
     def __call__(self, asset):
@@ -64,6 +80,8 @@ class AssetAttributesTests(TestCase):
         check('js/script.coffee', 'js/script.js')
         check('js/script.min.js', 'js/script.min.js')
         check('js/script.min.js.coffee', 'js/script.min.js')
+        check('images/logo.png', 'images/logo.png')
+        check('file', 'file')
 
     def test_search_paths(self):
         self.environment.mimetypes.register('.js', 'application/javascript')
